@@ -40,19 +40,31 @@ class RecordDraftService(RecordService):
     # Inherits record read, create, delete and update
     def search(self, identity, params=None, links_config=None,
                es_preference=None, **kwargs):
-        """Search for records matching the querystring."""
+        """Search for published records matching the querystring."""
         params = params or {}
         params.update(kwargs)
 
-        status = params.pop("status", "published")
-        record_cls = self.draft_cls if status == "draft" else self.record_cls
-
         return super().search(
             identity,
             params=params,
             links_config=links_config,
             es_preference=es_preference,
-            record_cls=record_cls,
+            record_cls=self.record_cls,
+            # we don't pass kwargs, because they have already been merged.
+        )
+
+    def search_drafts(self, identity, params=None, links_config=None,
+                      es_preference=None, **kwargs):
+        """Search for drafts records matching the querystring."""
+        params = params or {}
+        params.update(kwargs)
+
+        return super().search(
+            identity,
+            params=params,
+            links_config=links_config,
+            es_preference=es_preference,
+            record_cls=self.draft_cls,
             # we don't pass kwargs, because they have already been merged.
         )
 
@@ -174,25 +186,54 @@ class RecordDraftService(RecordService):
         db.session.commit()
         self.indexer.index(draft)
 
+        # Re index the record to trigger update of computed values in the
+        # available dumpers
+        self.indexer.index(record)
+
         return self.result_item(
             self, identity, draft, links_config=links_config)
 
     def publish(self, id_, identity, links_config=None):
-        """Publish a draft."""
+        """Publish a draft.
+
+        Idea:
+            - Get the draft from the data layer (draft is not passed in)
+            - Validate it more strictly than when it was originally saved
+              (drafts can be incomplete but only complete drafts can be turned
+              into records)
+            - Create or update associated (published) record with data
+
+        NOTE: This process of taking data from the database and validating it
+              back is tricky because there are a number of
+              data representations and transformations. There can be mistakes
+              within it as of writing. Don't take this flow as gospel yet.
+        """
         self.require_permission(identity, "publish")
 
-        # Get draft
+        # Get data layer draft
         draft = self.draft_cls.pid.resolve(id_, registered_only=False)
+        # Convert to service layer draft result item
+        draft_item = self.result_item(
+            self, identity, draft, links_config=None  # no need for links
+        )
+        # Convert to data projection i.e. draft result item's dict form. Since
+        # there are no "errors" bc projection is taken directly from
+        # DB, we can use draft_item.data. This dict form is what is
+        # serialized out/deserialized in so it "should" be valid input to load.
+        draft_data = draft_item.data
 
+        # Purely used for validation purposes although we may actually want to
+        # use it...
         data, _ = self.schema.load(
             identity,
-            data=draft.dumps(),
+            data=draft_data,
             pid=draft.pid,
             record=draft,
             raise_errors=True  # this is the default, but might as well be
                                # explicit
         )
 
+        # Create or update published record
         record = self.record_cls.create_or_update_from(draft)
 
         # Run components
@@ -206,7 +247,6 @@ class RecordDraftService(RecordService):
 
         record.commit()
         db.session.commit()
-
         draft.delete()
         db.session.commit()  # Persist DB
         self.indexer.delete(draft)
@@ -265,4 +305,9 @@ class RecordDraftService(RecordService):
         db.session.commit()
         self.indexer.delete(draft)
 
+        # Re index the record to trigger update of computed values in the
+        # available dumpers
+        if record:
+            self.indexer.index(record)
+
         return True
